package sun.net.www.protocol.http.logging;

import java.util.regex.Matcher;
import java.util.logging.LogRecord;
import java.util.regex.Pattern;
import java.util.logging.SimpleFormatter;

public class HttpLogFormatter extends SimpleFormatter
{
    private static volatile Pattern pattern;
    private static volatile Pattern cpattern;
    
    public HttpLogFormatter() {
        if (HttpLogFormatter.pattern == null) {
            HttpLogFormatter.pattern = Pattern.compile("\\{[^\\}]*\\}");
            HttpLogFormatter.cpattern = Pattern.compile("[^,\\] ]{2,}");
        }
    }
    
    @Override
    public String format(LogRecord record) {
        String sourceClassName = record.getSourceClassName();
        if (sourceClassName == null || (!sourceClassName.startsWith("sun.net.www.protocol.http") && !sourceClassName.startsWith("sun.net.www.http"))) {
            return super.format(record);
        }
        String message = record.getMessage();
        StringBuilder sb = new StringBuilder("HTTP: ");
        if (message.startsWith("sun.net.www.MessageHeader@")) {
            Matcher matcher3 = HttpLogFormatter.pattern.matcher(message);
            while (matcher3.find()) {
                String str = message.substring(matcher3.start() + 1, matcher3.end() - 1);
                if (str.startsWith("null: ")) {
                    str = str.substring(6);
                }
                if (str.endsWith(": null")) {
                    str = str.substring(0, str.length() - 6);
                }
                sb.append("\t").append(str).append("\n");
            }
        }
        else if (message.startsWith("Cookies retrieved: {")) {
            String s = message.substring(20);
            sb.append("Cookies from handler:\n");
            while (s.length() >= 7) {
                if (s.startsWith("Cookie=[")) {
                    String input = s.substring(8);
                    int index = input.indexOf("Cookie2=[");
                    if (index > 0) {
                        input = input.substring(0, index - 1);
                        s = input.substring(index);
                    }
                    else {
                        s = "";
                    }
                    if (input.length() < 4) {
                        continue;
                    }
                    Matcher matcher = HttpLogFormatter.cpattern.matcher(input);
                    while (matcher.find()) {
                        int start = matcher.start();
                        int end = matcher.end();
                        if (start >= 0) {
                            sb.append("\t").append(input.substring(start + 1, (end > 0) ? (end - 1) : (input.length() - 1))).append("\n");
                        }
                        else {
                            continue;
                        }
                    }
                }
                if (!s.startsWith("Cookie2=[")) {
                    continue;
                }
                String input2 = s.substring(9);
                int index2 = input2.indexOf("Cookie=[");
                if (index2 > 0) {
                    input2 = input2.substring(0, index2 - 1);
                    s = input2.substring(index2);
                }
                else {
                    s = "";
                }
                Matcher matcher2 = HttpLogFormatter.cpattern.matcher(input2);
                while (matcher2.find()) {
                    int start2 = matcher2.start();
                    int end2 = matcher2.end();
                    if (start2 >= 0) {
                        sb.append("\t").append(input2.substring(start2 + 1, (end2 > 0) ? (end2 - 1) : (input2.length() - 1))).append("\n");
                    }
                    else {
                        continue;
                    }
                }
            }
        }
        else {
            sb.append(message).append("\n");
        }
        return sb.toString();
    }
    
    static {
        HttpLogFormatter.pattern = null;
        HttpLogFormatter.cpattern = null;
    }
}
